/**
 * Copyright Promptu Systems Corporation 2016. All rights reserved.
 */
package bugzilla;

/**
 * The details of a bug mentioned in a p4 change description.
 *
 * @author Warwick Hunter
 * @since  2016-11-25
 */
public class BugMention implements Comparable<BugMention> {

    private final int m_bugNumber;
    private int       m_reviewNumber;
    private boolean   m_isFixed;

    public BugMention(int bugNumber) {
        m_bugNumber = bugNumber;
        m_isFixed = false;
    }

    @Override
    public String toString() {
        return String.format("BugMention [bugNumber=%d, reviewNumber=%d, isFixed=%s]", m_bugNumber, m_reviewNumber, m_isFixed);
    }

    @Override
    public int compareTo(BugMention other) {
        int comparison = Integer.compare(m_bugNumber, other.m_bugNumber);
        if (comparison != 0) {
            return comparison;
        }
        comparison = Integer.compare(m_reviewNumber, other.m_reviewNumber);
        if (comparison != 0) {
            return comparison;
        }
        return Boolean.compare(m_isFixed, other.m_isFixed);
    }


    public int getBugNumber() {
        return m_bugNumber;
    }

    public int getReviewNumber() {
        return m_reviewNumber;
    }

    public void setReviewNumber(int reviewNumber) {
        m_reviewNumber = reviewNumber;
    }

    public boolean isFixed() {
        return m_isFixed;
    }

    public void setFixed(boolean isFixed) {
        m_isFixed = isFixed;
    }
}